<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005022400)


$string['calendar'] = 'Kalenteri';
$string['calendarheading'] = '$a kalenteri';
$string['clickhide'] = 'piilota';
$string['clickshow'] = 'nyt';
$string['confirmeventdelete'] = 'Haluatko varmasti poistaa tmn tapahtuman';
$string['courseevents'] = 'Kurssin tapahtumat';
$string['day'] = 'piv';
$string['dayview'] = 'Pivnkym';
$string['daywithnoevents'] = 'Ei tapahtumia tlle pivlle';
$string['default'] = 'Oletus';
$string['deleteevent'] = 'Poista tapahtuma';
$string['detailedmonthview'] = 'Tarkennettu kuukausinkym';
$string['dstadjusttime'] = 'Siirr kelloa';
$string['dstat'] = 'kello';
$string['dstby'] = 'tmn verran:';
$string['dstdefaultpresetname'] = 'Uusi kesajan asetus';
$string['dsthumanreadable'] = 'Kuukauden $a->activate_index $a->activate_weekday aina {$a->activate_month}ssa, siirr kelloa $a->offset minuuttia $a->direction. Tm kellonajan muutos on voimassa aina {$a->deactivate_month}n $a->deactivate_index {$a->deactivate_weekday}hin.';
$string['dstof'] = 'tss kuussa:';
$string['dstonthe'] = 'Kuukauden';
$string['dstpresetactivated'] = 'Kesaika alkaa';
$string['dstpresetadjusttime'] = 'Kellon siirto';
$string['dstpresetdeactivated'] = 'Kesaika loppuu';
$string['dstpresetname'] = 'Asetuksen nimi';
$string['durationminutes'] = 'Kesto minuutteina';
$string['durationnone'] = 'Ilman kestoa';
$string['durationuntil'] = 'Pttymisaika';
$string['editevent'] = 'Muokkaa tapahtumaa';
$string['errorbeforecoursestart'] = 'Tapahtumaa ei voi asettaa alkavaksi ennen kurssin aloituspiv';
$string['errorinvaliddate'] = 'Pivmr virheellinen';
$string['errorinvalidminutes'] = 'Mrit kesto 1 ja 999 minuutin vlilt.';
$string['errorinvalidrepeats'] = 'Mrit tapahtumien mr 1 ja 99 vlill.';
$string['errornodescription'] = 'Tapahtuman kuvaus puuttuu';
$string['errornoeventname'] = 'Tapahtuman nimi puuttuu';
$string['eventdate'] = 'Pivmr';
$string['eventdescription'] = 'Tapahtuman kuvaus';
$string['eventduration'] = 'Kesto';
$string['eventendtime'] = 'Tapahtuman pttymisaika';
$string['eventinstanttime'] = 'kello';
$string['eventkind'] = 'Tapahtuman tyyppi';
$string['eventname'] = 'Nimi';
$string['eventrepeat'] = 'Toistot';
$string['eventsfor'] = '$a tapahtumat';
$string['eventstarttime'] = 'Tapahtuman alkamisaika';
$string['eventtime'] = 'kello';
$string['eventview'] = 'Tapahtumankym';
$string['expired'] = 'Tapahtuma on jo mennyt';
$string['explain_dstpreset'] = 'Alasvetovalikosta voit halutessasi valita alueen, jolla kesajan asetukset ovat kytss.';
$string['explain_dstpresetforced'] = 'Tmn asetuksen muuttaminen ei ole sallittua.';
$string['explain_lookahead'] = 'Tm oletusasetus mritt, kuinka monen pivn pss tulevaisuudessa tapahtuman pit olla, jotta se nytettisiin \"tulevana tapahtumana\". Tapahtumia, jotka alkavat myhemmin, ei nytet koskaan tulevien tapahtumien listassa. Huomaa, ett <strong>ei ole mitn takeita</strong> siit, ett kaikki tmn ajan sisll olevat tapahtumat nytettisiin tulevien listassa; mikli niit on paljon (enemmn kuin asetus \"Tulevien tapahtumien listan maksimikoko\", kaukaisimmat tulevista tapahtumista eivt ny listassa.';
$string['explain_maxevents'] = 'Tm asetus mritt tulevien tapahtumien listan maksimikoon. Mikli valitset thn suuren luvun, saattaa tulevien tapahtumien lista vied huomattavan paljon tilaa ruudultasi.';
$string['explain_persistflt'] = 'Jos tm asetus on pll, Moodle muistaa kalenterista valitsemiesi tapahtumien piilotuksen ja nyttmisen asetukset mys kirjautumiskertojen vlill.';
$string['explain_startwday'] = 'Tm asetus mritt tavan, jolla kuukausittainen kalenteri nytetn. Kyt tt asettaaksesi nkymlle tavan, johon olet tottunut.';
$string['explain_timeformat'] = 'Voit nytt ajat joko 12 tai 24 tunnin muodossa. Jos valitset \"oletus\", valinta suoritetaan sivuston asetusten mukaisesti.';
$string['first'] = 'ensimminen';
$string['fri'] = 'pe';
$string['friday'] = 'perjantai';
$string['globalevents'] = 'Yhteiset tapahtumat';
$string['gotocalendar'] = 'Siirry kalenteriin';
$string['groupevents'] = 'Ryhmn tapahtumat';
$string['hidden'] = 'Piilotettu';
$string['last'] = 'viimeinen';
$string['manyevents'] = '$a tapahtumaa';
$string['mon'] = 'ma';
$string['monday'] = 'maanantai';
$string['monthlyview'] = 'Kuukausinkym';
$string['newevent'] = 'Uusi tapahtuma';
$string['notusingdst'] = 'Kesaika ei ole kytss';
$string['noupcomingevents'] = 'Ei tulevia tapahtumia';
$string['nth'] = '{$a}.';
$string['oneevent'] = '1 tapahtuma';
$string['pref_dstpreset'] = 'Kesaika';
$string['pref_lookahead'] = 'Tulevien tapahtumien tarkastelu';
$string['pref_maxevents'] = 'Tulevien tapahtumien listan maksimikoko';
$string['pref_persistflt'] = 'Tallenna tapahtumien piilotusvalinnat';
$string['pref_startwday'] = 'Viikon ensimminen piv';
$string['pref_timeformat'] = 'Kellonajan muoto';
$string['preferences'] = 'Asetukset';
$string['preferences_available'] = 'Henkilkohtaiset asetuksesi';
$string['repeatnone'] = 'Ei toistoja';
$string['repeatweeksl'] = 'Toista viikoittain';
$string['repeatweeksr'] = 'tapahtumaa';
$string['sat'] = 'la';
$string['saturday'] = 'lauantai';
$string['shown'] = 'nkyviss';
$string['spanningevents'] = 'Tapahtumia kynniss parhaillaan';
$string['sun'] = 'su';
$string['sunday'] = 'sunnuntai';
$string['thu'] = 'to';
$string['thursday'] = 'torstai';
$string['timeformat_12'] = '12-tuntinen (AP/IP)';
$string['timeformat_24'] = '24-tuntinen';
$string['timeforward'] = 'eteenpin';
$string['timerewind'] = 'taaksepin';
$string['today'] = 'tnn';
$string['tomorrow'] = 'huomenna';
$string['tt_deleteevent'] = 'Poista tapahtuma';
$string['tt_editevent'] = 'Muokkaa tapahtumaa';
$string['tt_hidecourse'] = 'Kurssin tapahtumat nytetn (piilota)';
$string['tt_hideglobal'] = 'Yleiset tapahtumat nytetn (piilota)';
$string['tt_hidegroups'] = 'Ryhmn tapahtumat nytetn (piilota)';
$string['tt_hideuser'] = 'Kyttjn tapahtumat nytetn (piilota)';
$string['tt_showcourse'] = 'Kurssin tapahtumat piilotettuna (nyt)';
$string['tt_showglobal'] = 'Yleiset tapahtumat piilotettuna (nyt)';
$string['tt_showgroups'] = 'Ryhmn tapahtumat piilotettuna (nyt)';
$string['tt_showuser'] = 'Kyttjn tapahtumat piilotettuna (nyt)';
$string['tue'] = 'ti';
$string['tuesday'] = 'tiistai';
$string['typecourse'] = 'koko kurssille';
$string['typegroup'] = 'ryhmlle';
$string['typesite'] = 'koko sivustolle';
$string['typeuser'] = 'oma tapahtuma';
$string['upcomingevents'] = 'Tulevat tapahtumat';
$string['userevents'] = 'Omat tapahtumat';
$string['wed'] = 'ke';
$string['wednesday'] = 'keskiviikko';
$string['yesterday'] = 'eilen';

?>
